//
//  ViewController.m
//  AlivcLiveCaptureTest
//
//  Created by lyz on 16/7/29.
//  Copyright © 2016年 Alibaba. All rights reserved.
//

#import "ViewController.h"
#import "StartLiveViewController.h"
#import "LiveRoomViewController.h"
#import "LoginViewController.h"
#import "AFNetworking.h"
#import "SDRefresh.h"
#import "AlivcLiveAlertView.h"
#import "ViewListTableViewCell.h"
#import "AlivcRequestManager.h"
#import "RoomInfoModel.h"
#import "SendMessageManager.h"

//#define kTestPlay

@interface ViewController ()<UITableViewDelegate, UITableViewDataSource, LoginViewControllerDelegate>

@property (nonatomic, strong) UITableView *listTableView;
@property (nonatomic, strong) UIButton *createBtn;
@property (nonatomic, strong) UIButton *liveButton;
@property (nonatomic, strong) UILabel *noLiveLabel;
@property (nonatomic, strong) NSMutableArray *listDataArray;

@property (nonatomic, strong) NSString *uid;
@property (nonatomic, strong) NSString *name;
@property (nonatomic, assign) NSInteger playURLFormat;

@property (nonatomic, strong) SDRefreshHeaderView *refreshHeaderView;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.listDataArray = [NSMutableArray array];

    [self setupSubViews];

    // Do any additional setup after loading the view, typically from a nib.
}

- (void)viewDidAppear:(BOOL)animated {
    
    [super viewDidAppear:animated];

    if(!self.uid) {
        [self loginAlivc];
        return;
    }
    
    [self requestLiveList];
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)loginAlivc {
    
    LoginViewController *loginVC = [[LoginViewController alloc] init];
    loginVC.delegate = self;
    [self presentViewController:loginVC animated:YES completion:nil];
}

#pragma mark - Request
- (void)requestLiveList {

    [SendMessageManager getAppLiveList:^(NSMutableArray *roomInfos, NSError *error) {
        
        if (error) {
            NSLog(@"播放列表获取失败:%@", error);
            [self.refreshHeaderView endRefreshing];
            return ;
        }
        
        [self.listDataArray removeAllObjects];
        for (RoomInfoModel* model in roomInfos) {
            [self.listDataArray addObject:model];
        }
        [self.refreshHeaderView endRefreshing];
        [self.listTableView reloadData];
        
        if ([self.listDataArray count] == 0) {
            self.navigationItem.title = @"";
            self.createBtn.hidden = NO;
            self.noLiveLabel.hidden = NO;
            self.liveButton.hidden = YES;
        }
        else {
            self.navigationItem.title = @"正在直播";
            self.createBtn.hidden = YES;
            self.noLiveLabel.hidden = YES;
            self.liveButton.hidden = NO;
        }
    }];
    
    return;
}


#pragma mark - UI

- (void)loadListTableView {
    
    self.listTableView = [[UITableView alloc] initWithFrame: CGRectMake(0, 64, kAlivcLiveScreenWidth, kAlivcLiveScreenHeight)];
    self.listTableView.delegate = self;
    self.listTableView.dataSource = self;
    self.listTableView.separatorStyle = UITableViewCellSeparatorStyleSingleLine;
    [self.listTableView registerClass:[ViewListTableViewCell class] forCellReuseIdentifier:@"listTableViewID"];
    self.listTableView.tableFooterView = [[UIView alloc] init];
    [self.view addSubview:self.listTableView];
    
}

-(void)leftBar1Clicked:(NSObject*)sender
{
    LoginViewController *loginVC = [[LoginViewController alloc] init];
    [self presentViewController:loginVC animated:YES completion:nil];
}

- (void)setupSubViews {
    
    UIButton *_backButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [_backButton addTarget:self action:@selector(leftBar1Clicked:) forControlEvents:UIControlEventTouchUpInside];
    [_backButton setBackgroundImage:[UIImage imageNamed:@"back"] forState:UIControlStateNormal];
    [self.view addSubview:_backButton];
    [_backButton sizeToFit];
    UIBarButtonItem *item1 = [[UIBarButtonItem alloc] initWithCustomView:_backButton];
    self.navigationItem.leftBarButtonItems = @[item1];

    self.navigationItem.title = @"正在直播";
    self.navigationController.navigationBar.barTintColor =  [UIColor colorWithRed:0xf2 / 255.0 green:0xf2 / 255.0 blue:0xf2 / 255.0 alpha:1];
    [self loadListTableView];
    
    self.liveButton = [UIButton buttonWithType:(UIButtonTypeCustom)];
    self.liveButton.frame = CGRectMake((kAlivcLiveScreenWidth - 56) / 2, (kAlivcLiveScreenHeight - 80), 56, 56);
    [self.liveButton setBackgroundImage:[UIImage imageNamed:@"Create"] forState:(UIControlStateNormal)];
    [self.liveButton addTarget:self action:@selector(startLiveButtonAction:) forControlEvents:(UIControlEventTouchUpInside)];
    self.liveButton.hidden = YES;
    [self.view addSubview: self.liveButton];
    
    // 下拉刷新
    self.refreshHeaderView = [SDRefreshHeaderView refreshView];
    [self.refreshHeaderView addToScrollView: self.listTableView];
    self.refreshHeaderView.isEffectedByNavigationController = YES;
    [self.refreshHeaderView addTarget:self refreshAction:@selector(requestLiveList)];
    
#ifdef kTestPlay
    [self initSegmentedControl];
#endif
    
    self.createBtn = [UIButton buttonWithType:(UIButtonTypeRoundedRect)];
    self.createBtn.frame = CGRectMake((self.view.frame.size.width-150)/2, self.view.frame.size.height-100, 150, 40);
    [self.createBtn addTarget:self action:@selector(startLiveButtonAction:) forControlEvents:(UIControlEventTouchUpInside)];
    [self.createBtn setTitleColor:kAlivcColor forState:(UIControlStateNormal)];
    [self.createBtn setTitleColor:[UIColor grayColor] forState:(UIControlStateSelected)];
    [self.createBtn.titleLabel setFont:[UIFont systemFontOfSize:17.f]];
    [self.createBtn setBackgroundColor:[UIColor colorWithRed:0x87 / 255.0 green:0x4b / 255.0 blue:0xe0 / 255.0 alpha:1]];
    [self.createBtn setTitle:@"创建我的直播" forState:UIControlStateNormal];
    self.createBtn.clipsToBounds = YES;
    self.createBtn.layer.cornerRadius = 20;
    [self.createBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    self.createBtn.hidden = YES;
    [self.view addSubview:self.createBtn];
    
    self.noLiveLabel = [[UILabel alloc] init];
    self.noLiveLabel.text = @"当前还没有直播";
    self.noLiveLabel.textColor = [UIColor grayColor];
    self.noLiveLabel.frame = CGRectMake((self.view.frame.size.width-200)/2, 250, 200, 40);
    self.noLiveLabel.font = [UIFont systemFontOfSize:24.f];
    self.noLiveLabel.textAlignment = NSTextAlignmentCenter;
    self.noLiveLabel.hidden = YES;
    [self.view addSubview:self.noLiveLabel];
}


- (void)initSegmentedControl {
    
    NSArray *segmentedData = [[NSArray alloc] initWithObjects:@"180P",@"360P",@"720P",nil];
    UISegmentedControl *segmentedControl = [[UISegmentedControl alloc] initWithItems:segmentedData];
    segmentedControl.frame = CGRectMake(0, kAlivcLiveScreenHeight - 30, kAlivcLiveScreenWidth, 30);
    segmentedControl.tintColor = kAlivcColor;
    segmentedControl.selectedSegmentIndex = 1;
    self.playURLFormat = 1;

    [segmentedControl addTarget:self action:@selector(segmentControlAction:) forControlEvents:(UIControlEventValueChanged)];
    
    [self.view addSubview:segmentedControl];
}

#pragma mark - UITableViewDelegate

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    return self.listDataArray.count;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [UIScreen mainScreen].bounds.size.width+52;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    ViewListTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"listTableViewID" forIndexPath:indexPath];
    
    if (self.listDataArray.count > indexPath.row) {
        
        RoomInfoModel *model = self.listDataArray[indexPath.row];
        
        cell.nameLabel.text = [NSString stringWithFormat:@"姓名:%@ (ID:%@)", model.name, model.uid];
    }
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
    RoomInfoModel *model = self.listDataArray[indexPath.row];
    
    if (model.status == 1) {        
        LiveRoomViewController *liveRoomVC = [[LiveRoomViewController alloc] init];
        liveRoomVC.playUrl = model.playUrl;
        liveRoomVC.roomId = model.roomId;
        liveRoomVC.hostUid = model.uid;
        liveRoomVC.liveName = model.name;
        liveRoomVC.userUid = self.uid;
        UIPasteboard *pasteboard = [UIPasteboard generalPasteboard];
        pasteboard.string = liveRoomVC.playUrl;
//        NSString *play = [[model.rtmpPlayUrl componentsSeparatedByString:@"_mhd"] firstObject];
        liveRoomVC.playUrl = model.rtmpPlayUrl;

        [self presentViewController:liveRoomVC animated:YES completion:nil];

    } else {
        AlivcLiveAlertView *alert = [[AlivcLiveAlertView alloc] initWithTitle:@"提示" icon:nil message:@"当前主播还未开始直播，请稍后下拉刷新列表重试" delegate:nil buttonTitles:@"OK",nil];
        [alert showInView:self.view];
    }
    
}



#pragma mark - LoginVCDelegate
- (void)LoginViewControllerSendBackUid:(NSString *)uid name:(NSString *)name {
    self.uid = uid;
    self.name = name;
}

#pragma mark - Action
- (void)startLiveButtonAction:(UIButton *)sender {
    
    StartLiveViewController *startLiveVC = [[StartLiveViewController alloc] init];
    startLiveVC.uid = self.uid;
    startLiveVC.liveName = self.name;
    
#ifdef kTestPlay
    startLiveVC.videoSize = self.playURLFormat;
#endif
    
    
    [self presentViewController:startLiveVC animated:YES completion:nil];
}

- (void)segmentControlAction:(UISegmentedControl *)sender {
    self.playURLFormat = sender.selectedSegmentIndex;
}


@end
